@@ -10,12 +10,12 @@ testthat::test_that("ci.limits breaks if logic vector", {
 })
 
 testthat::test_that("ci.limits works ok with string or numeric vectors", {
-  testthat::expect_s3_class(object = rsimsum::simsum(data = tt, estvarname = "diff", true = -1, se = "se", ci.limits = c("lower", "upper"), methodvar = "method", by = "dgm"), class = "simsum")
+  testthat::expect_s3_class(object = rsimsum::simsum(data = tt, estvarname = "diff", true = -1, se = "se", ci.limits = c("conf.low", "conf.high"), methodvar = "method", by = "dgm"), class = "simsum")
   testthat::expect_s3_class(object = rsimsum::simsum(data = tt, estvarname = "diff", true = -1, se = "se", ci.limits = c(-2, 0), methodvar = "method", by = "dgm"), class = "simsum")
 })
 
 testthat::test_that("ci.limits with string vector yields different values of coverage than the default", {
-  s <- rsimsum::simsum(data = tt, estvarname = "diff", true = -1, se = "se", ci.limits = c("lower", "upper"), methodvar = "method", by = "dgm")
+  s <- rsimsum::simsum(data = tt, estvarname = "diff", true = -1, se = "se", ci.limits = c("conf.low", "conf.high"), methodvar = "method", by = "dgm")
   s <- tidy(s, stats = "cover")
   sdef <- rsimsum::simsum(data = tt, estvarname = "diff", true = -1, se = "se", methodvar = "method", by = "dgm")
   sdef <- tidy(sdef, stats = "cover")
